/**
 * 
 */
package com.example.layouttest;


import java.io.Serializable;

import com.example.layouttest.event.ShowCityBuilderEvent;
import com.example.layouttest.event.TourDetailsSelectedEvent;
import com.example.layouttest.presenter.AbstractPresenter;
import com.example.layouttest.presenter.CityBuilderPresenter;
import com.example.layouttest.presenter.CityEditorPresenter;
import com.example.layouttest.presenter.TourDetailsEditorPresenter;
import com.example.layouttest.presenter.TourEditorPresenter;
import com.example.layouttest.view.AppView;
import com.example.layouttest.view.AppViewImpl;
import com.example.layouttest.view.AppView.MenuItemId;
import com.vaadin.event.EventRouter;
import com.vaadin.ui.Panel;

public class AppController 
    extends AbstractPresenter<AppView, AppView.Presenter> 
    implements AppView.Presenter, Serializable {

    private static final long serialVersionUID = 1L;
    
    private EventRouter eventBus;

    private CityBuilderPresenter cityBuilderPresenter;
    private TourDetailsEditorPresenter tourDetailsEditorPresenter;    
    /** Placeholder of the main view. */
    private Panel panel;

    public void setCityBuilderPresenter(CityBuilderPresenter cityBuilderPresenter) {
        this.cityBuilderPresenter = cityBuilderPresenter;
    }

    public void setTourDetailsEditorPresenter(TourDetailsEditorPresenter tourDetailsEditorPresenter) {
        this.tourDetailsEditorPresenter = tourDetailsEditorPresenter;
    }
    
    public AppController(EventRouter eventBus) {
    	this.eventBus = eventBus;
    	init();
    }
    
    void init() {
        eventBus.addListener(TourDetailsSelectedEvent.class, this, "showTourDetailsEditor");
        eventBus.addListener(ShowCityBuilderEvent.class, this, "showCityBuilder");
    }

    @Override
    protected AppView createView() {
        return new AppViewImpl();
    }   
    
    /* (non-Javadoc)
     * @see hu.pocketguide.server.web.vaadin.eventmgr.presenter.Presenter#go(com.vaadin.ui.Panel)
     */
    @Override
    public void go(Panel panel) {
        this.panel = panel;
        this.panel.setContent(getView().asLayout());
        
        showCityBuilder(null);
    }

    public void showCityBuilder(ShowCityBuilderEvent event) {
    	cityBuilderPresenter.setCityEditorPresenter(new CityEditorPresenter(eventBus));
    	cityBuilderPresenter.setTourEditorPresenter(new TourEditorPresenter(eventBus));
        cityBuilderPresenter.go(getView().getMainPanel());
    }
    
    public void showTourDetailsEditor(TourDetailsSelectedEvent event) {
        tourDetailsEditorPresenter.go(getView().getMainPanel());
    }     
}
