/**
 * 
 */
package com.example.layouttest.view;

import com.example.layouttest.Browser;
import com.example.layouttest.EditorPanel;
import com.vaadin.data.Property.ValueChangeEvent;
import com.vaadin.data.Property.ValueChangeListener;
import com.vaadin.data.util.HierarchicalContainer;
import com.vaadin.event.Action;
import com.vaadin.event.Action.Handler;
import com.vaadin.ui.Alignment;
import com.vaadin.ui.Button;
import com.vaadin.ui.HorizontalLayout;
import com.vaadin.ui.Label;
import com.vaadin.ui.Layout;
import com.vaadin.ui.Panel;
import com.vaadin.ui.VerticalLayout;
import com.vaadin.ui.Button.ClickEvent;
import com.vaadin.ui.Button.ClickListener;


public class CityBuilderViewImpl 
    extends HorizontalLayout implements CityBuilderView, Handler {

    private static final long serialVersionUID = 1L;
    
    private Presenter presenter;
    private Browser citiesTree;
    /** The placeholder for editors. */
    private EditorPanel editorPanel;
    
    private Action actionTourDetails;
    private Action[] tourContextMenuActions;
    

    public CityBuilderViewImpl() {
        
        actionTourDetails = new Action("Tour Details");
        tourContextMenuActions = new Action[] {actionTourDetails};
        
        VerticalLayout vLayout = new VerticalLayout();
        vLayout.setStyleName("cityBrowser");
        vLayout.setWidth("200px");
        vLayout.setSpacing(true);
        
        vLayout.addComponent(new Label("CityBuilderView"));
        
        // Tree-view
        citiesTree = new Browser();
        citiesTree.addListener(new ValueChangeListener() {
            
            @Override
            public void valueChange(ValueChangeEvent event) {
                String selectedCityId = (String)event.getProperty().getValue();
                if (selectedCityId != null) {
                    presenter.onItemSelected(selectedCityId);
                }
            }
        });
        citiesTree.addActionHandler(this);
        vLayout.addComponent(citiesTree);
        addComponent(vLayout);
        
        // The editor panel
        this.editorPanel = new EditorPanel();
        addComponent(this.editorPanel);
    }

    @Override
    public void setCities(HierarchicalContainer citiesContainer) {
        citiesTree.setContainerDataSource(citiesContainer);
    }

    @Override
    public void setPresenter(Presenter presenter) {
        this.presenter = presenter;
    }

    @Override
    public Layout asLayout() {
        return this;
    }

    @Override
    public Panel getEditorPanel() {
        return this.editorPanel;
    }

    @Override
    public String getSelectedItemId() {
        return (String)citiesTree.getValue();
    }

    @Override
    public void setSelectedItemId(String itemId) {
        String parentId = (String)citiesTree.getParent(itemId);
        if (parentId != null) {
            citiesTree.expandItem(parentId);
        }
        citiesTree.select(itemId);
    }

    @Override
    public Action[] getActions(Object target, Object sender) {
        return tourContextMenuActions;
    }

    @Override
    public void handleAction(Action action, Object sender, Object target) {
        setSelectedItemId((String)target);
        if (action == actionTourDetails) {
            // Allow children for the target item, and expand it
            citiesTree.setChildrenAllowed(target, false);
            //citiesTree.expandItem(target);
            presenter.onTourDetails((String)target);
        }
    }

}
